c        printout error message on error out.
c
      subroutine cerrorMsg(msg, needrtn)
      implicit none
#include  "Zmanagerp.h"

      external cblkManager

      character*(*) msg !  input.  message to be printed
      integer  needrtn  !  input. 0  --> stop 9999,else control is returned
      integer klena

      write(ErrorOut, '(a)') msg(1:klena(msg))
      if(needrtn .eq. 0) stop 9999
      end

